var class_ogre_1_1_d3_d9_render_system =
[
    [ "MultiheadUseType", "class_ogre_1_1_d3_d9_render_system.html#ac150cea205fda65dacbccaee1d5d652f", [
      [ "mutAuto", "class_ogre_1_1_d3_d9_render_system.html#ac150cea205fda65dacbccaee1d5d652fa25921c72928c345bce879cdeb59ea4de", null ],
      [ "mutYes", "class_ogre_1_1_d3_d9_render_system.html#ac150cea205fda65dacbccaee1d5d652faf9d4681736aed408d4446783840b775f", null ],
      [ "mutNo", "class_ogre_1_1_d3_d9_render_system.html#ac150cea205fda65dacbccaee1d5d652fa0e39e4e40a49121c32929470d9829f38", null ]
    ] ],
    [ "D3D9RenderSystem", "class_ogre_1_1_d3_d9_render_system.html#a14dbc5ade147a1ff11f7f7e2dff70053", null ],
    [ "~D3D9RenderSystem", "class_ogre_1_1_d3_d9_render_system.html#a5fcc5cf6ff472ea542bb69aeb48b9b01", null ],
    [ "_addManualDepthBuffer", "class_ogre_1_1_d3_d9_render_system.html#aa08b2dd098cf209cd3f1102c46cf3c21", null ],
    [ "_addMetrics", "class_ogre_1_1_d3_d9_render_system.html#a54ebaf329b7173ef06cbfcd0dff64cb5", null ],
    [ "_beginFrame", "class_ogre_1_1_d3_d9_render_system.html#a3b458922197e5a3502b29e9bfe016cdf", null ],
    [ "_beginFrameOnce", "class_ogre_1_1_d3_d9_render_system.html#ada60763d5b8ef9cfba1c77ecfe3e4188", null ],
    [ "_checkTextureFilteringSupported", "class_ogre_1_1_d3_d9_render_system.html#a09b739bb7b2d3c3aff1fecece56e9baa", null ],
    [ "_cleanupDepthBuffers", "class_ogre_1_1_d3_d9_render_system.html#a3c813348d2b65c9bcc7076811c5be436", null ],
    [ "_cleanupDepthBuffers", "class_ogre_1_1_d3_d9_render_system.html#affaba55ebbb835d47398ba424d2191cf", null ],
    [ "_cleanupDepthBuffers", "class_ogre_1_1_d3_d9_render_system.html#a93ef27c77c394d18f8c1ba6361dbef98", null ],
    [ "_clearStateAndFlushCommandBuffer", "class_ogre_1_1_d3_d9_render_system.html#a2ee7864ccf7579b46082f2b694d6586a", null ],
    [ "_convertOpenVrProjectionMatrix", "class_ogre_1_1_d3_d9_render_system.html#ad05022b35e523cdba22d993a51fc4b78", null ],
    [ "_convertProjectionMatrix", "class_ogre_1_1_d3_d9_render_system.html#a2228dcfce5ec360f8f421f9544872f01", null ],
    [ "_createDepthBufferFor", "class_ogre_1_1_d3_d9_render_system.html#a949fa1062460e37e5a9ca9815486d56d", null ],
    [ "_createRenderWindow", "class_ogre_1_1_d3_d9_render_system.html#ab120136ac65bef3def024f27532c03fb", null ],
    [ "_createRenderWindow", "class_ogre_1_1_d3_d9_render_system.html#ad8469f0aa267bf80682e08cdd0a41aaf", null ],
    [ "_createRenderWindows", "class_ogre_1_1_d3_d9_render_system.html#af2e127de3a611d547520a667fe067f29", null ],
    [ "_createRenderWindows", "class_ogre_1_1_d3_d9_render_system.html#a2d1a6b690161dcd972d7cfc13b59dc10", null ],
    [ "_dereferenceSharedDepthBuffer", "class_ogre_1_1_d3_d9_render_system.html#a24604b2949b6dfe884b7d87b9ebaf0cc", null ],
    [ "_descriptorSetSamplerCreated", "class_ogre_1_1_d3_d9_render_system.html#a5b3f8e6370d6df438402da2053e0cb54", null ],
    [ "_descriptorSetSamplerDestroyed", "class_ogre_1_1_d3_d9_render_system.html#afdea9fc18369642840cc829cd00bfddf", null ],
    [ "_descriptorSetTexture2Created", "class_ogre_1_1_d3_d9_render_system.html#a520883a11540189688188087c364c612", null ],
    [ "_descriptorSetTexture2Destroyed", "class_ogre_1_1_d3_d9_render_system.html#a9b63f3873cf44d872b67399fa10e5d9c", null ],
    [ "_descriptorSetTextureCreated", "class_ogre_1_1_d3_d9_render_system.html#ab0a2269caa58940a6618c81800fdd266", null ],
    [ "_descriptorSetTextureDestroyed", "class_ogre_1_1_d3_d9_render_system.html#a87217b97e113b837eac511853235d4d2", null ],
    [ "_descriptorSetUavCreated", "class_ogre_1_1_d3_d9_render_system.html#ab011696d2aa484f57f0e69ae685f085a", null ],
    [ "_descriptorSetUavDestroyed", "class_ogre_1_1_d3_d9_render_system.html#a6fee529f7b119ec00cd327d1e8deaa77", null ],
    [ "_disableTextureUnit", "class_ogre_1_1_d3_d9_render_system.html#a0f35bab2afa97804cf8323d0205cd0c5", null ],
    [ "_dispatch", "class_ogre_1_1_d3_d9_render_system.html#a861e0f346f675c6fa688e522c0754ad8", null ],
    [ "_endFrame", "class_ogre_1_1_d3_d9_render_system.html#aff3564dce1811300a2d4e7a65e4e9c66", null ],
    [ "_endFrameOnce", "class_ogre_1_1_d3_d9_render_system.html#a7918658f5c363617c53f6179d23e63fc", null ],
    [ "_getCurrentRenderViewport", "class_ogre_1_1_d3_d9_render_system.html#a51cbd7a790f8bad97ac8983e00fcbfb2", null ],
    [ "_getDefaultViewportMaterialScheme", "class_ogre_1_1_d3_d9_render_system.html#a6a719f86bcb5458d55bd0cd887f3ed3e", null ],
    [ "_getDepthStencilFormatFor", "class_ogre_1_1_d3_d9_render_system.html#a756e9227a2d0147e31100ce041d4f9cb", null ],
    [ "_hlmsBlendblockCreated", "class_ogre_1_1_d3_d9_render_system.html#ac33cff318b8ae9c4f1b9a35b97250322", null ],
    [ "_hlmsBlendblockDestroyed", "class_ogre_1_1_d3_d9_render_system.html#a494fc2da2cb98d016803868180cdcbb9", null ],
    [ "_hlmsComputePipelineStateObjectCreated", "class_ogre_1_1_d3_d9_render_system.html#ab7691a6fe2d57613a8ba6a0b5780b313", null ],
    [ "_hlmsComputePipelineStateObjectDestroyed", "class_ogre_1_1_d3_d9_render_system.html#aa89a15ea101f8a99889847555725cc9c", null ],
    [ "_hlmsMacroblockCreated", "class_ogre_1_1_d3_d9_render_system.html#a4ff8308ab34ef75574f1f5cc005d0f8c", null ],
    [ "_hlmsMacroblockDestroyed", "class_ogre_1_1_d3_d9_render_system.html#a93c80e0f7c8dfc22f197a7211a5401f1", null ],
    [ "_hlmsPipelineStateObjectCreated", "class_ogre_1_1_d3_d9_render_system.html#ac682bcc56a7fb4cb8ae83772dfc6b7f3", null ],
    [ "_hlmsPipelineStateObjectDestroyed", "class_ogre_1_1_d3_d9_render_system.html#a9120e92d45da9294119cc88f3ad8bd19", null ],
    [ "_hlmsSamplerblockCreated", "class_ogre_1_1_d3_d9_render_system.html#a5df47d554298bec7130841b77b301034", null ],
    [ "_hlmsSamplerblockDestroyed", "class_ogre_1_1_d3_d9_render_system.html#ab4c5501448cb75312320baac3fb05d1d", null ],
    [ "_initialise", "class_ogre_1_1_d3_d9_render_system.html#acb3570aea045a845b12171db4458b21c", null ],
    [ "_makeRsProjectionMatrix", "class_ogre_1_1_d3_d9_render_system.html#a37208fe7f2e29b71a2972defdf9d04b2", null ],
    [ "_pauseFrame", "class_ogre_1_1_d3_d9_render_system.html#a6eba351f3da4503d5c3b1d67789f2754", null ],
    [ "_render", "class_ogre_1_1_d3_d9_render_system.html#a05164d117632c60852cbcc6c21fd957b", null ],
    [ "_render", "class_ogre_1_1_d3_d9_render_system.html#a1224b23cee7a4967f75cb947ba185b99", null ],
    [ "_render", "class_ogre_1_1_d3_d9_render_system.html#ac95209c361f6d09fb6e0af0f6d4b4107", null ],
    [ "_render", "class_ogre_1_1_d3_d9_render_system.html#a8a6d8da446a59c5036f3e6711ab4196e", null ],
    [ "_render", "class_ogre_1_1_d3_d9_render_system.html#a30f4a6909be427c7f7624c9275a66a60", null ],
    [ "_render", "class_ogre_1_1_d3_d9_render_system.html#a49106178b38e763d6ee457bd03ffeec4", null ],
    [ "_renderEmulated", "class_ogre_1_1_d3_d9_render_system.html#a6cbeadf8057f487949b2966e4e78f1f2", null ],
    [ "_renderEmulated", "class_ogre_1_1_d3_d9_render_system.html#a9ea7f02b26e51ac73243be2224af53f6", null ],
    [ "_renderEmulatedNoBaseInstance", "class_ogre_1_1_d3_d9_render_system.html#a7d6c7c84f9b85cb342dd559de75d585f", null ],
    [ "_renderEmulatedNoBaseInstance", "class_ogre_1_1_d3_d9_render_system.html#a4e62ece32366cca0909ca82eef6d174a", null ],
    [ "_renderNoBaseInstance", "class_ogre_1_1_d3_d9_render_system.html#adf4faec7fb049bc5092605c526cf1d72", null ],
    [ "_renderNoBaseInstance", "class_ogre_1_1_d3_d9_render_system.html#a85520f23e22840e951573681d4baef4f", null ],
    [ "_resetMetrics", "class_ogre_1_1_d3_d9_render_system.html#ac277fde4bc118aab022798181aa9afeb", null ],
    [ "_resumeFrame", "class_ogre_1_1_d3_d9_render_system.html#a21e6f22c4f85330f8f546f4469f23fbe", null ],
    [ "_setAlphaRejectSettings", "class_ogre_1_1_d3_d9_render_system.html#ab63c18908e608834b601298afd2da197", null ],
    [ "_setBindingType", "class_ogre_1_1_d3_d9_render_system.html#ae197c344b0b2dce1739e3c566c280f8c", null ],
    [ "_setColourBufferWriteEnabled", "class_ogre_1_1_d3_d9_render_system.html#a0f781d5921649ee87d5a0a1753b8e081", null ],
    [ "_setComputePso", "class_ogre_1_1_d3_d9_render_system.html#af401f9ec22a0f9e21b6166fb263029f9", null ],
    [ "_setCullingMode", "class_ogre_1_1_d3_d9_render_system.html#a96a7b98979ad56646ad87c4e327098cd", null ],
    [ "_setCurrentDeviceFromTexture", "class_ogre_1_1_d3_d9_render_system.html#af5514030509c865cc21022534f3a416e", null ],
    [ "_setDepthBias", "class_ogre_1_1_d3_d9_render_system.html#a7830b7940977d3ad920d0984c06113be", null ],
    [ "_setDepthBufferCheckEnabled", "class_ogre_1_1_d3_d9_render_system.html#a28dd997892ac1cb3f0b5f2babfa112d7", null ],
    [ "_setDepthBufferFunction", "class_ogre_1_1_d3_d9_render_system.html#a87d8a1dde9baf36fdc68f5a36c983383", null ],
    [ "_setDepthBufferParams", "class_ogre_1_1_d3_d9_render_system.html#a0d4aad4a09e5ccb9edea8814b53c3142", null ],
    [ "_setDepthBufferWriteEnabled", "class_ogre_1_1_d3_d9_render_system.html#aa44f574d9b7aeec5be3b652dbae21d79", null ],
    [ "_setGeometryTexture", "class_ogre_1_1_d3_d9_render_system.html#a59066ea64e39a91f9e190178400c090e", null ],
    [ "_setHlmsBlendblock", "class_ogre_1_1_d3_d9_render_system.html#a5ee8c138e30e64518b26267b8d38ee37", null ],
    [ "_setHlmsMacroblock", "class_ogre_1_1_d3_d9_render_system.html#a35fb7b14d5d628855cc736032f026b63", null ],
    [ "_setHlmsSamplerblock", "class_ogre_1_1_d3_d9_render_system.html#a9a4f74e34a4506733d8285dd7b6ca89c", null ],
    [ "_setIndirectBuffer", "class_ogre_1_1_d3_d9_render_system.html#afec276677b0b3d5f44adacc451ebfb3f", null ],
    [ "_setPipelineStateObject", "class_ogre_1_1_d3_d9_render_system.html#ad4f1cf52c31104a2652ef2f985474c12", null ],
    [ "_setPointParameters", "class_ogre_1_1_d3_d9_render_system.html#a82e47ef0c94c5f7d87199151ca811ff5", null ],
    [ "_setPointSpritesEnabled", "class_ogre_1_1_d3_d9_render_system.html#a8087fcbe4777015df90f574b61fdfa67", null ],
    [ "_setPolygonMode", "class_ogre_1_1_d3_d9_render_system.html#a0d5d7d3f33d4a8a6ee1ce2e416d7320a", null ],
    [ "_setProgramsFromHlms", "class_ogre_1_1_d3_d9_render_system.html#a5efd3027ef492b16edbcd7b1c04362d7", null ],
    [ "_setProjectionMatrix", "class_ogre_1_1_d3_d9_render_system.html#a1fd0bcf3a5888f44e241e964a0532c98", null ],
    [ "_setRenderOperation", "class_ogre_1_1_d3_d9_render_system.html#a0d1c42482bd2fbc446637af69ab19e3d", null ],
    [ "_setRenderTarget", "class_ogre_1_1_d3_d9_render_system.html#a195727cf757652f7f744a0fa27d19ea8", null ],
    [ "_setSamplers", "class_ogre_1_1_d3_d9_render_system.html#af919a4eb70f53fb3224727e4ad461bb5", null ],
    [ "_setSamplersCS", "class_ogre_1_1_d3_d9_render_system.html#afdf1ef7aca956c3109bf17daa6be3dca", null ],
    [ "_setSceneBlending", "class_ogre_1_1_d3_d9_render_system.html#aae2238e6e28dc099ed8cafad1b58b8d1", null ],
    [ "_setSeparateSceneBlending", "class_ogre_1_1_d3_d9_render_system.html#aebfca89852cb822a7dcfe3aa5288999f", null ],
    [ "_setSurfaceParams", "class_ogre_1_1_d3_d9_render_system.html#a868c258f27f871c839f24505c1542caa", null ],
    [ "_setTessellationDomainTexture", "class_ogre_1_1_d3_d9_render_system.html#aba600f21b87a9f259f435645b5e8e686", null ],
    [ "_setTessellationHullTexture", "class_ogre_1_1_d3_d9_render_system.html#ac95050584b686d5ccbe6464642a56c12", null ],
    [ "_setTexture", "class_ogre_1_1_d3_d9_render_system.html#acc8659aa8149972ca8c1175199110d7d", null ],
    [ "_setTexture", "class_ogre_1_1_d3_d9_render_system.html#a7fd55c280458295605c05553b6d37b2c", null ],
    [ "_setTextureAddressingMode", "class_ogre_1_1_d3_d9_render_system.html#a52779ba1276abbe4b5da48c2018b2061", null ],
    [ "_setTextureBlendMode", "class_ogre_1_1_d3_d9_render_system.html#ad0ce107404650d8b2ba8fcfba1448b60", null ],
    [ "_setTextureBorderColour", "class_ogre_1_1_d3_d9_render_system.html#a8f2284cd8c24afda7c14f9570f400698", null ],
    [ "_setTextureCoordCalculation", "class_ogre_1_1_d3_d9_render_system.html#aa54b0c2ad942d41897c0b8a0a8e44166", null ],
    [ "_setTextureCoordSet", "class_ogre_1_1_d3_d9_render_system.html#acfaf7c8ec448362a48a5ab1a026909dd", null ],
    [ "_setTextureLayerAnisotropy", "class_ogre_1_1_d3_d9_render_system.html#a665c77f780de89e0af79c3d774d9c2f6", null ],
    [ "_setTextureMatrix", "class_ogre_1_1_d3_d9_render_system.html#aaf51e7092d88a781953f3d0d0048eb52", null ],
    [ "_setTextureMipmapBias", "class_ogre_1_1_d3_d9_render_system.html#a4f573f2b71583712a1dac603f6917f98", null ],
    [ "_setTextureProjectionRelativeTo", "class_ogre_1_1_d3_d9_render_system.html#a91e7ee7dd1f244ffa9a0681efb6fae6c", null ],
    [ "_setTextures", "class_ogre_1_1_d3_d9_render_system.html#afdfcf9972c149816915fc518529b5c48", null ],
    [ "_setTextures", "class_ogre_1_1_d3_d9_render_system.html#a6bd0650487d7d4897d83855c2a83a307", null ],
    [ "_setTexturesCS", "class_ogre_1_1_d3_d9_render_system.html#ac72b57b87519c77eb348309816d56604", null ],
    [ "_setTexturesCS", "class_ogre_1_1_d3_d9_render_system.html#af456e585b06fdaa2159c86915a7f87ba", null ],
    [ "_setTextureUnitCompareEnabled", "class_ogre_1_1_d3_d9_render_system.html#a497f1ce8b52f61c024848f513f2a7456", null ],
    [ "_setTextureUnitCompareFunction", "class_ogre_1_1_d3_d9_render_system.html#a9e34d9fe95dbca71ec671b6372c0c5a8", null ],
    [ "_setTextureUnitFiltering", "class_ogre_1_1_d3_d9_render_system.html#a2844693c27bb55b93af8098fd658fb38", null ],
    [ "_setTextureUnitSettings", "class_ogre_1_1_d3_d9_render_system.html#ad504623eff0678f9f79b075f32673414", null ],
    [ "_setUavCS", "class_ogre_1_1_d3_d9_render_system.html#a6c579fe141e844884fc87ef581e86651", null ],
    [ "_setVertexArrayObject", "class_ogre_1_1_d3_d9_render_system.html#af2133a26a36f26813a1de7651bb62e8d", null ],
    [ "_setVertexTexture", "class_ogre_1_1_d3_d9_render_system.html#a349ff5d559210fe9d1b733add4ddd350", null ],
    [ "_setVertexTexture", "class_ogre_1_1_d3_d9_render_system.html#a0471211b21215ae5ae25438cacd5d060", null ],
    [ "_setViewMatrix", "class_ogre_1_1_d3_d9_render_system.html#af879a2bcdca5a9c4e944cb2976786a40", null ],
    [ "_setViewport", "class_ogre_1_1_d3_d9_render_system.html#a85ad53d4f860030b319ce0420f4ece2a", null ],
    [ "_setWorldMatrices", "class_ogre_1_1_d3_d9_render_system.html#a9442fcdf97b2723c588dee0489f2aefc", null ],
    [ "_setWorldMatrix", "class_ogre_1_1_d3_d9_render_system.html#a736da4898f04646bfc42e7b7d70e0ca7", null ],
    [ "_startLegacyV1Rendering", "class_ogre_1_1_d3_d9_render_system.html#a5d6299db093e1604716d153db0bbafbe", null ],
    [ "_update", "class_ogre_1_1_d3_d9_render_system.html#a7c12dd90845c77aa98606fd33efc958f", null ],
    [ "_useLights", "class_ogre_1_1_d3_d9_render_system.html#a1ed8dc6bed45eea7372025d8c8b7a67a", null ],
    [ "addClipPlane", "class_ogre_1_1_d3_d9_render_system.html#abe0fbe6b4972baf14137235fe3f6c499", null ],
    [ "addClipPlane", "class_ogre_1_1_d3_d9_render_system.html#a2eb75175291761881bdc0d73ec379089", null ],
    [ "addListener", "class_ogre_1_1_d3_d9_render_system.html#ada5d01c8a4eb8e64140d92fce245800c", null ],
    [ "addSharedListener", "class_ogre_1_1_d3_d9_render_system.html#a89fe3734e6d495bfb73624ef269305cf", null ],
    [ "areFixedFunctionLightsInViewSpace", "class_ogre_1_1_d3_d9_render_system.html#a008131b65568c0bf072ae3a96203d6c0", null ],
    [ "beginGPUSampleProfile", "class_ogre_1_1_d3_d9_render_system.html#a05c1e2721a42dec9c6482aeb0aeab097", null ],
    [ "beginProfileEvent", "class_ogre_1_1_d3_d9_render_system.html#ac5910601e68f4c7c08370e2b74066d9b", null ],
    [ "beginRenderPassDescriptor", "class_ogre_1_1_d3_d9_render_system.html#a44cb87de8b2c7b80b9a8eceaea20b961", null ],
    [ "bindGpuProgram", "class_ogre_1_1_d3_d9_render_system.html#a82c436739e35880bf9a03d3296b93e4d", null ],
    [ "bindGpuProgramParameters", "class_ogre_1_1_d3_d9_render_system.html#a2d49ad76497b871e32bf18b6fd2edf5a", null ],
    [ "bindGpuProgramPassIterationParameters", "class_ogre_1_1_d3_d9_render_system.html#a89794d945fa06756b8fabab0aa400981", null ],
    [ "checkExtension", "class_ogre_1_1_d3_d9_render_system.html#ae869e9f5ca12313ee49fa0743dbcf1f3", null ],
    [ "clearFrameBuffer", "class_ogre_1_1_d3_d9_render_system.html#a80605199eceb6f34f01230242d1f8c41", null ],
    [ "clearFrameBuffer", "class_ogre_1_1_d3_d9_render_system.html#a746af1925b9e07bfc96075b192c19333", null ],
    [ "compositorWorkspaceBegin", "class_ogre_1_1_d3_d9_render_system.html#a90d567191f24a30cb806ab0a146bf8b2", null ],
    [ "compositorWorkspaceEnd", "class_ogre_1_1_d3_d9_render_system.html#ab732bb02d12b702817772ccf4973a47f", null ],
    [ "compositorWorkspaceUpdate", "class_ogre_1_1_d3_d9_render_system.html#a2d2d776006ee7a9fa8fae1ac14265177", null ],
    [ "convertColourValue", "class_ogre_1_1_d3_d9_render_system.html#a80d543b61b1152b0dd0049961be4798e", null ],
    [ "createHardwareOcclusionQuery", "class_ogre_1_1_d3_d9_render_system.html#aceacaef86b50bc57a0eed5793ee26e74", null ],
    [ "createMultiRenderTarget", "class_ogre_1_1_d3_d9_render_system.html#aa2511e52bd08dced3e30f7002ff67c48", null ],
    [ "createRenderPassDescriptor", "class_ogre_1_1_d3_d9_render_system.html#acfcf7b4ecf6426ce8358f21fb868321a", null ],
    [ "createStereoDriver", "class_ogre_1_1_d3_d9_render_system.html#a296a4b8cb73c61dced451b6e23e95919", null ],
    [ "debugAnnotationPop", "class_ogre_1_1_d3_d9_render_system.html#afcb3669378e8730fe2c48d7fa6d8a3c1", null ],
    [ "debugAnnotationPush", "class_ogre_1_1_d3_d9_render_system.html#af880df1d878f28b0aea0f1f818ea940d", null ],
    [ "deinitGPUProfiling", "class_ogre_1_1_d3_d9_render_system.html#ab72dcb00f1cd7eb283521f684f566c58", null ],
    [ "destroyHardwareOcclusionQuery", "class_ogre_1_1_d3_d9_render_system.html#ac4c60bf4c5d4347fd2b9346a90545e2b", null ],
    [ "destroyRenderPassDescriptor", "class_ogre_1_1_d3_d9_render_system.html#a60e5ffa2ec8f2709435c3d11e8a321f6", null ],
    [ "destroyRenderTarget", "class_ogre_1_1_d3_d9_render_system.html#a13fb04ce75bdf6920f3ce3628a19b610", null ],
    [ "destroyRenderWindow", "class_ogre_1_1_d3_d9_render_system.html#a36a560a1e0e171b9a1a19a2748e6dd15", null ],
    [ "detachRenderTarget", "class_ogre_1_1_d3_d9_render_system.html#a8cc3e0c6a7cad3efc6f8c4e004c9cfa6", null ],
    [ "determineFSAASettings", "class_ogre_1_1_d3_d9_render_system.html#abeb5bc1a5691a572c5dc2f4775cf76c5", null ],
    [ "enableClipPlane", "class_ogre_1_1_d3_d9_render_system.html#aebb369ceba620861ccd3ff8a1cead931", null ],
    [ "endCopyEncoder", "class_ogre_1_1_d3_d9_render_system.html#a30b893cdd07ccd24f95623ebef2668b7", null ],
    [ "endGpuDebuggerFrameCapture", "class_ogre_1_1_d3_d9_render_system.html#a0a72b69bed67cdf99239d884748bcb08", null ],
    [ "endGPUSampleProfile", "class_ogre_1_1_d3_d9_render_system.html#abc10607326985e9220635a80fba6c20e", null ],
    [ "endProfileEvent", "class_ogre_1_1_d3_d9_render_system.html#ae849367c0ad6d28ecc8db5d95b3e56d7", null ],
    [ "endRenderPassDescriptor", "class_ogre_1_1_d3_d9_render_system.html#abf307f8d33424add34986bbe82de7b77", null ],
    [ "executeRenderPassDescriptorDelayedActions", "class_ogre_1_1_d3_d9_render_system.html#a3dc08052db357beff034cad183fdfadc", null ],
    [ "executeResourceTransition", "class_ogre_1_1_d3_d9_render_system.html#ad6efb4ed490715cf068fca69b689403d", null ],
    [ "fireDeviceEvent", "class_ogre_1_1_d3_d9_render_system.html#ace53b06d3e61511f9b2dc6156e31c9a9", null ],
    [ "fireSharedEvent", "class_ogre_1_1_d3_d9_render_system.html#add0b3b86b8ec2f51d8973b6b3e06448e", null ],
    [ "flushCommands", "class_ogre_1_1_d3_d9_render_system.html#a03042760fb5ad088f8c73883f9d7fe14", null ],
    [ "getActiveD3D9Device", "class_ogre_1_1_d3_d9_render_system.html#a73585609cd73845b9217349725ca278b", null ],
    [ "getActiveD3D9DeviceIfExists", "class_ogre_1_1_d3_d9_render_system.html#a14902091a74d2a3799b2929f11b2dabe", null ],
    [ "getBarrierSolver", "class_ogre_1_1_d3_d9_render_system.html#a66b206faf53b0b3ff54b10153c76b66f", null ],
    [ "getBoundUav", "class_ogre_1_1_d3_d9_render_system.html#afb6f61d5c70531c1eb718cdfbefb0330", null ],
    [ "getCapabilities", "class_ogre_1_1_d3_d9_render_system.html#aa6c951fc82f49ccf22787fcd1e7ee451", null ],
    [ "getColourVertexElementType", "class_ogre_1_1_d3_d9_render_system.html#a1725114e0149f084486dc60abc62bbdc", null ],
    [ "getConfigOptions", "class_ogre_1_1_d3_d9_render_system.html#aedbb8040eb6e5e9258056680d31bd567", null ],
    [ "getCurrentPassDescriptor", "class_ogre_1_1_d3_d9_render_system.html#a56f9ba2b074ce74b1e1aed293b5fc6a0", null ],
    [ "getCurrentRenderViewports", "class_ogre_1_1_d3_d9_render_system.html#a5c3cbe94dd790fa8083aedbbc146edcb", null ],
    [ "getCustomAttribute", "class_ogre_1_1_d3_d9_render_system.html#a97e2c11d3822c064ccb8ef0b52acf289", null ],
    [ "getDebugShaders", "class_ogre_1_1_d3_d9_render_system.html#a05dbfafd87ccda8119c289c266e41ec1", null ],
    [ "getDepthBufferFor", "class_ogre_1_1_d3_d9_render_system.html#af088707ac4e0c0a0904a50fdc74b7325", null ],
    [ "getDeviceManager", "class_ogre_1_1_d3_d9_render_system.html#afaf9cf2f1d9cd94d8be47d9047533544", null ],
    [ "getDirect3D9", "class_ogre_1_1_d3_d9_render_system.html#a62aa32d65cc848c3149767be38e0c244", null ],
    [ "getDisplayMonitorCount", "class_ogre_1_1_d3_d9_render_system.html#a44795018c7a6f424849c23cb3947a240", null ],
    [ "getDriverVersion", "class_ogre_1_1_d3_d9_render_system.html#ac7d381c6d59bc7b3d4483746f04e2a90", null ],
    [ "getErrorDescription", "class_ogre_1_1_d3_d9_render_system.html#aaeb93c2e45c81e44b79eb7c2d37bea84", null ],
    [ "getFriendlyName", "class_ogre_1_1_d3_d9_render_system.html#a081f3261185c0e1da3ca9deca506288a", null ],
    [ "getGlobalInstanceVertexBuffer", "class_ogre_1_1_d3_d9_render_system.html#a2a859eea18cd0c3cf0c7876bbab862a4", null ],
    [ "getGlobalInstanceVertexBufferVertexDeclaration", "class_ogre_1_1_d3_d9_render_system.html#ad1a30f09bb15daac26e8e10901525214", null ],
    [ "getGlobalNumberOfInstances", "class_ogre_1_1_d3_d9_render_system.html#af41e08cc1bc54e34d0314f4c9ffa58f6", null ],
    [ "getHorizontalTexelOffset", "class_ogre_1_1_d3_d9_render_system.html#aaa6341e3fe439fffeff5bfffa48ec0e6", null ],
    [ "getInvertedClipSpaceY", "class_ogre_1_1_d3_d9_render_system.html#a9742abc3eb4609b4fc9cbd7df1051661", null ],
    [ "getInvertVertexWinding", "class_ogre_1_1_d3_d9_render_system.html#a133c89c9430091210e01ac44d638a0a3", null ],
    [ "getMaxBoundViewports", "class_ogre_1_1_d3_d9_render_system.html#a3a83f5a8128df163c7bed5a87a7ee923", null ],
    [ "getMaximumDepthInputValue", "class_ogre_1_1_d3_d9_render_system.html#ab55596f38bfc1ba9721eaa121166d7a5", null ],
    [ "getMetrics", "class_ogre_1_1_d3_d9_render_system.html#a2c8b21df3f79f69fbcf304fa131cb1f9", null ],
    [ "getMinimumDepthInputValue", "class_ogre_1_1_d3_d9_render_system.html#a14c20f8c89b3ef2a8c71daa22f9f02bd", null ],
    [ "getMultiheadUse", "class_ogre_1_1_d3_d9_render_system.html#a7f5e2beb4bd0d894ee99c6468ba20ee7", null ],
    [ "getMutableCapabilities", "class_ogre_1_1_d3_d9_render_system.html#a7125b8a614f54a9750b85c5eba62b474", null ],
    [ "getName", "class_ogre_1_1_d3_d9_render_system.html#a4062d64949c3f8ed6001af07fecca244", null ],
    [ "getNativeShadingLanguageVersion", "class_ogre_1_1_d3_d9_render_system.html#a9d89d5e2e2f0c2c30e72032eae4482ec", null ],
    [ "getNumPriorityConfigOptions", "class_ogre_1_1_d3_d9_render_system.html#ad48a2e651a88a5f3eecdf60e452878e5", null ],
    [ "getPixelFormatToShaderType", "class_ogre_1_1_d3_d9_render_system.html#a7040f99ad34bec1fe332a95e1ad6b961", null ],
    [ "getPriorityConfigOption", "class_ogre_1_1_d3_d9_render_system.html#a9b1ee9f299e9097bec1185a4ec478cf7", null ],
    [ "getRenderDocApi", "class_ogre_1_1_d3_d9_render_system.html#a5d8f84c242a383d007beabf72b11ef76", null ],
    [ "getRenderSystemEvents", "class_ogre_1_1_d3_d9_render_system.html#aeca02905d47fa75bfb87a4c07e68d02d", null ],
    [ "getResourceCreationDevice", "class_ogre_1_1_d3_d9_render_system.html#ad177ce11d6941a706429db4a973faad4", null ],
    [ "getResourceCreationDeviceCount", "class_ogre_1_1_d3_d9_render_system.html#af9b728ddf675afcecfafd0d4d335c63c", null ],
    [ "getResourceManager", "class_ogre_1_1_d3_d9_render_system.html#ac27c2134455ce86c7886c8450a0393ae", null ],
    [ "getRSDepthRange", "class_ogre_1_1_d3_d9_render_system.html#a4be8db64459468925237b45d87958f26", null ],
    [ "getStencilBufferParams", "class_ogre_1_1_d3_d9_render_system.html#a0a9b24e0640279f6b6fa90613727d585", null ],
    [ "getTextureGpuManager", "class_ogre_1_1_d3_d9_render_system.html#a2fc23c559d6e15f6a2d0841bbdf7135a", null ],
    [ "getVaoManager", "class_ogre_1_1_d3_d9_render_system.html#adacd8a9cdfaf24b2aab87289de657189", null ],
    [ "getVerticalTexelOffset", "class_ogre_1_1_d3_d9_render_system.html#a39666e7dd9fc27b22c82b05715fb3ff5", null ],
    [ "getWBufferEnabled", "class_ogre_1_1_d3_d9_render_system.html#a644d2fd38872cf323c50f63148d27d02", null ],
    [ "hasAnisotropicMipMapFilter", "class_ogre_1_1_d3_d9_render_system.html#a659cb3dfd72379833b0b4898d99f9a48", null ],
    [ "initConfigOptions", "class_ogre_1_1_d3_d9_render_system.html#a7c380aa6256e6ad8cd0278cfd4108515", null ],
    [ "initGPUProfiling", "class_ogre_1_1_d3_d9_render_system.html#a417adea02b63de86acf6ae6edaa13ac8", null ],
    [ "IsActiveDeviceLost", "class_ogre_1_1_d3_d9_render_system.html#a683991dc15e1d0c67213b96f9ac7753b", null ],
    [ "isDirectX9Ex", "class_ogre_1_1_d3_d9_render_system.html#a377991202bcd3b2ade63fe13f0540039", null ],
    [ "isGpuProgramBound", "class_ogre_1_1_d3_d9_render_system.html#a1ac003196b5b51384f714924a0041081", null ],
    [ "isReverseDepth", "class_ogre_1_1_d3_d9_render_system.html#a780e5c6941c2f5d1f699dbf3e8c5b869", null ],
    [ "isSameLayout", "class_ogre_1_1_d3_d9_render_system.html#a387d5fa07b1c096496ce6a97c4f68505", null ],
    [ "isStaticBufferLockable", "class_ogre_1_1_d3_d9_render_system.html#abaa7a52e12f93b4dfe8cad18828ffb5b", null ],
    [ "loadRenderDocApi", "class_ogre_1_1_d3_d9_render_system.html#ab750bf02b8afe5aefce3a4594541904d", null ],
    [ "markProfileEvent", "class_ogre_1_1_d3_d9_render_system.html#a489d99fe770e4c105434ed13911ce350", null ],
    [ "operator delete", "class_ogre_1_1_d3_d9_render_system.html#a8357fe4fb4849772b94baa4bf47c7ded", null ],
    [ "operator delete", "class_ogre_1_1_d3_d9_render_system.html#acb46d4b0a597156d9ba5abc39d127792", null ],
    [ "operator delete", "class_ogre_1_1_d3_d9_render_system.html#a1c727e879a260c37b00ce5505fe8e144", null ],
    [ "operator delete[]", "class_ogre_1_1_d3_d9_render_system.html#a93e6a86dde5483c053ca0f2a85bbfd6c", null ],
    [ "operator delete[]", "class_ogre_1_1_d3_d9_render_system.html#a595ea4c05da8aa987d3800e65d23355d", null ],
    [ "operator new", "class_ogre_1_1_d3_d9_render_system.html#ad1f1a983f9e2dfddee802c47bb0b1ca9", null ],
    [ "operator new", "class_ogre_1_1_d3_d9_render_system.html#ab422c67a2c8844f410fe822a357cba3b", null ],
    [ "operator new", "class_ogre_1_1_d3_d9_render_system.html#a63fc6bdc2eb6aeac24898a77ec5e2023", null ],
    [ "operator new[]", "class_ogre_1_1_d3_d9_render_system.html#adce32528577d71b228692df906ecd17c", null ],
    [ "operator new[]", "class_ogre_1_1_d3_d9_render_system.html#aed1464ac3de21ff20db8f9f1f8608dc7", null ],
    [ "postExtraThreadsStarted", "class_ogre_1_1_d3_d9_render_system.html#add5efc1032e4e0cc1540811b1b68113d", null ],
    [ "preExtraThreadsStarted", "class_ogre_1_1_d3_d9_render_system.html#a1054440c7aa6a82c82c3062ecb0822d7", null ],
    [ "queueBindUAVs", "class_ogre_1_1_d3_d9_render_system.html#abd681ab591e98cfe37c76bdac2357d6e", null ],
    [ "registerThread", "class_ogre_1_1_d3_d9_render_system.html#a7bbc4c2f2fcfdc3f4e0a6e01250e39b2", null ],
    [ "reinitialise", "class_ogre_1_1_d3_d9_render_system.html#aad47c7460bff0b9a631b3eb17e296309", null ],
    [ "removeListener", "class_ogre_1_1_d3_d9_render_system.html#a7d9e3b4369f98e46dbea4cb4b9390f9d", null ],
    [ "removeSharedListener", "class_ogre_1_1_d3_d9_render_system.html#a0c9650fccf5a5e54b8b933786bdbe4fb", null ],
    [ "resetClipPlanes", "class_ogre_1_1_d3_d9_render_system.html#a46a9b1385638112a80bf22fa1a5bf531", null ],
    [ "reverseCompareFunction", "class_ogre_1_1_d3_d9_render_system.html#a6a34f2ded473d4cbaeda6e954f76dbaf", null ],
    [ "setAmbientLight", "class_ogre_1_1_d3_d9_render_system.html#a5c0492ef2b162b8d0297e355c6d93592", null ],
    [ "setClipPlane", "class_ogre_1_1_d3_d9_render_system.html#a2c6b6c60a60e9bfbf784596e3273e34a", null ],
    [ "setClipPlanes", "class_ogre_1_1_d3_d9_render_system.html#a23cc0a7d87b77ec3d0a34e92335bec1a", null ],
    [ "setConfigOption", "class_ogre_1_1_d3_d9_render_system.html#a1f3c8023280ce8b5915434b2e7f52d20", null ],
    [ "setCurrentPassIterationCount", "class_ogre_1_1_d3_d9_render_system.html#a207d38c53699525e2e49ee167f9c8eb5", null ],
    [ "setDebugShaders", "class_ogre_1_1_d3_d9_render_system.html#a17c8936bc83639fb0a79efb18e4c20df", null ],
    [ "setDeriveDepthBias", "class_ogre_1_1_d3_d9_render_system.html#a927af19c2746aa2dd37018434bfc09f4", null ],
    [ "setDrawBuffer", "class_ogre_1_1_d3_d9_render_system.html#a869123f35563093de0f4fe68321b9b4b", null ],
    [ "setGlobalInstanceVertexBuffer", "class_ogre_1_1_d3_d9_render_system.html#a8c8297b96b0ab6c9d71c462c27695955", null ],
    [ "setGlobalInstanceVertexBufferVertexDeclaration", "class_ogre_1_1_d3_d9_render_system.html#aa3c004940bc1701a50644a65b02d3386", null ],
    [ "setGlobalNumberOfInstances", "class_ogre_1_1_d3_d9_render_system.html#a3e31b243ba86e2114925a99b2c2825e1", null ],
    [ "setInvertVertexWinding", "class_ogre_1_1_d3_d9_render_system.html#a697f9a8c12f2d08ccc6185cd7992c238", null ],
    [ "setMetricsRecordingEnabled", "class_ogre_1_1_d3_d9_render_system.html#aabd963520ca3e4e48ad5d64eabc4d76d", null ],
    [ "setScissorTest", "class_ogre_1_1_d3_d9_render_system.html#ada9466da79cf86fde16473cc8bf2c728", null ],
    [ "setStencilBufferParams", "class_ogre_1_1_d3_d9_render_system.html#a8aad4909174796d54e9b1b56784c4baf", null ],
    [ "setStencilBufferParams", "class_ogre_1_1_d3_d9_render_system.html#a62c4d393915276eb56752890a0029f92", null ],
    [ "setStencilCheckEnabled", "class_ogre_1_1_d3_d9_render_system.html#a17c198d30e84af9d8456b3f9198df09e", null ],
    [ "setUavStartingSlot", "class_ogre_1_1_d3_d9_render_system.html#a2d0de2f7b75ffb2d4048534ebe90bb73", null ],
    [ "setVertexBufferBinding", "class_ogre_1_1_d3_d9_render_system.html#a1819f0182b2c7ee533cf1032786d6d08", null ],
    [ "setVertexBufferBinding", "class_ogre_1_1_d3_d9_render_system.html#a4e565e4d5edfeedc47f8cc10dbccc3df", null ],
    [ "setVertexDeclaration", "class_ogre_1_1_d3_d9_render_system.html#a014e9b7fe6828806a7234f3115d029b8", null ],
    [ "setVertexDeclaration", "class_ogre_1_1_d3_d9_render_system.html#ad11519e92283a6cb4186dc618e037eec", null ],
    [ "setWBufferEnabled", "class_ogre_1_1_d3_d9_render_system.html#a01c339f6e89d82b526fb7725424a4263", null ],
    [ "shutdown", "class_ogre_1_1_d3_d9_render_system.html#af14f1a6b539a896178cebfd8a6282fa7", null ],
    [ "startGpuDebuggerFrameCapture", "class_ogre_1_1_d3_d9_render_system.html#afe7705e26f10dccebf2e6db0b3d6859e", null ],
    [ "unbindGpuProgram", "class_ogre_1_1_d3_d9_render_system.html#a08255da85acf7431528d739c77d37ec3", null ],
    [ "unregisterThread", "class_ogre_1_1_d3_d9_render_system.html#acca4cb7d57e8b3a190d4599e0f0ac340", null ],
    [ "updateCompositorManager", "class_ogre_1_1_d3_d9_render_system.html#a41328026d8be0e7143402a914f707cf9", null ],
    [ "useCustomRenderSystemCapabilities", "class_ogre_1_1_d3_d9_render_system.html#a6219a2d1f92be5548983a03de9522365", null ],
    [ "validateConfigOptions", "class_ogre_1_1_d3_d9_render_system.html#ac674dcd0e1b47a07723fe341f06eef6d", null ],
    [ "validateDevice", "class_ogre_1_1_d3_d9_render_system.html#a913bd8f0e2e19cf356ccaa3bed31543e", null ],
    [ "validateSampleDescription", "class_ogre_1_1_d3_d9_render_system.html#a1681d824b46321ab26f5566371c9fcb8", null ],
    [ "D3D9Device", "class_ogre_1_1_d3_d9_render_system.html#a62a49b9f66b36b9be215f88e190366a2", null ],
    [ "D3D9DeviceManager", "class_ogre_1_1_d3_d9_render_system.html#aec82c6ec0be39f7ecb3e0d165125a540", null ]
];